@@ -1,7 +1,5 @@
 import os
 
-import sphinx_py3doc_enhanced_theme
-
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.autosummary',
@@ -13,17 +11,17 @@ extensions = [
     'sphinx.ext.extlinks',
 ]
 if os.getenv('SPELLCHECK'):
-    extensions += 'sphinxcontrib.spelling',
+    extensions += ('sphinxcontrib.spelling',)
     spelling_show_suggestions = True
     spelling_lang = 'en_US'
 
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'pytest-cov'
-year = '2016'
+year = '2010-2024'
 author = 'pytest-cov contributors'
 copyright = f'{year}, {author}'
-version = release = '4.1.0'
+version = release = '5.0.0'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -31,19 +29,14 @@ extlinks = {
     'issue': ('https://github.com/pytest-dev/pytest-cov/issues/%s', '#'),
     'pr': ('https://github.com/pytest-dev/pytest-cov/pull/%s', 'PR #'),
 }
-
-html_theme = "sphinx_py3doc_enhanced_theme"
-html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
+html_theme = 'furo'
 html_theme_options = {
-    'githuburl': 'https://github.com/pytest-dev/pytest-cov/'
+    'githuburl': 'https://github.com/pytest-dev/pytest-cov/',
 }
 
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
-html_split_index = True
-html_sidebars = {
-   '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
-}
+html_split_index = False
 html_short_title = f'{project}-{version}'
 
 napoleon_use_ivar = True
